@@ -7,7 +7,6 @@ use Carp;
 use CPANPLUS::Backend;
 use CPANPLUS::Configure;
 use CPANPLUS::Error;
-use CPANPLUS::Internals::Constants;
 use POSIX qw( O_CREAT O_RDWR O_RDONLY );         # for SDBM_File
 use SDBM_File;
 use File::Fetch;
@@ -32,10 +31,7 @@ our %EXPORT_TAGS = (
   'default'  => [ qw( mark test excluded ) ],
 );
 
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our @EXPORT    = ( @{ $EXPORT_TAGS{'default'} } );
-
-$VERSION = '0.45_01';
+$VERSION = '0.02';
 
 {
   my %Checked;
@@ -45,7 +41,7 @@ $VERSION = '0.45_01';
 sub _connect_db {
   my $self = shift;
   return if $TiedObj;
-  my $filename = catfile( $self->{conf}->get_conf('base'), DATABASE_FILE );
+  my $filename = catfile( CPANPLUS::Internals::Utils->_home_dir(), '.cpanplus', DATABASE_FILE );
   $TiedObj = tie %Checked, 'SDBM_File', $filename, O_CREAT|O_RDWR, 0644;
   $self->{checked} = \%Checked;
 }
@@ -60,40 +56,24 @@ sub _disconnect_db {
 
 sub new {
   my $package = shift;
-  my $nconf = shift if ref $_[0] and $_[0]->isa('CPANPLUS::Configure');
 
   $ENV{AUTOMATED_TESTING} = 1;
   $ENV{PERL_MM_USE_DEFAULT} = 1; # despite verbose setting
-  $ENV{PERL_EXTUTILS_AUTOINSTALL} = '--defaultdeps';
+  $ENV{PERL5_CPANPLUS_VERBOSE} = 1; # set verbosity of CPANPLUS
 
-  my $conf = $nconf || CPANPLUS::Configure->new();
+  my $conf = CPANPLUS::Configure->new();
 
   # Override configure settings
   $conf->set_conf( prereqs => 2 ); # force to ask callback
   $conf->set_conf( skiptest => 0 ); 
-  $conf->set_conf( no_update => 1 )
-    if glob( catfile( $conf->get_conf('base'), $conf->_get_source('stored') .'*'. STORABLE_EXT, ) );
   $conf->set_conf( dist_type => 'CPANPLUS::Dist::YACSmoke' ); # this is where the magic happens.
-  $conf->set_conf( cpantest => 'dont_cc' ); # Yes, we want to report test results. But not CC
+  $conf->set_conf( cpantest => 1 ); # Yes, we want to report test results.
   $conf->set_conf( verbose => 1 ); # set verbosity to true.
 
-  unless ( defined $ENV{MAILDOMAIN} ) {
-     my $hostpart = ( split /\@/, ( $conf->get_conf( 'email' ) || 'smoker@cpantesters.org' ) )[1];
-     $ENV{MAILDOMAIN} = $hostpart =~ /^(cpan\.org|gmail\.com)$/i ? 'cpantesters.org' : $hostpart;
-  }
-
-  if ( $^V gt v5.9.5 ) {
-     $conf->set_conf( prefer_makefile => 0 ); # Prefer Build.PL if we have M::B
-  }
-  else {
-     eval "require Module::Build"; 
-     $conf->set_conf( prefer_makefile => 0 ) unless $@; # 
-  }
-
   my $cb   = CPANPLUS::Backend->new($conf);
 
   my $exclude_dists;
-  my $config_file = catfile( $conf->get_conf('base'), CONFIG_FILE );
+  my $config_file = catfile( CPANPLUS::Internals::Utils->_home_dir(), '.cpanplus', CONFIG_FILE );
   if ( -r $config_file ) {
      my $cfg = Config::IniFiles->new(-file => $config_file);
      my @list = $cfg->val( 'CONFIG', 'exclude_dists' );
@@ -154,7 +134,6 @@ sub test {
      };
   }
 
-  $self->{cpanplus}->save_state();
   return 1;
 }
 
@@ -342,7 +321,7 @@ sub _download_list {
   my $self  = shift;
 
   my $path  = catdir( CPANPLUS::Internals::Utils->_home_dir(), '.cpanplus' );
-  my $local = catfile( $path, RECENT_FILE );
+  my $local = catfile( $path, RECENT_FILE ); # catfile
 
   my $hosts = $self->{conf}->get_conf('hosts');
   my $h_ind = 0;
@@ -366,7 +345,7 @@ sub _download_list {
     or croak("Cannot access local RECENT file [$local]: $!\n");
   while (<$fh>) {
     next    unless(/^authors/);
-    next    unless(/\.(?:tar\.(?:bz2|gz|Z)|t(?:gz|bz)|(?<!ppm\.)zip|pm.gz)\n$/i);
+    next    unless(/\.(tar\.gz|tgz|tar\.bz2|zip)\n$/);
     s!authors/id/!!;
     chomp;
     push @testlist, $_;
@@ -425,7 +404,7 @@ The C<exclude_dists> setting, which is laid out as:
   mod_perl
   HERE
 
-The above would then ignore any distribution that includes the string
+The above would then ignore any distribution that include the string
 'mod_perl' in its name. This is useful for distributions which use
 external C libraries, which are not installed, or for which testing
 is problematic.
@@ -535,44 +514,6 @@ The object interface is created normally through the test() or mark() functions
 
 =back 
 
-=head1 ENVIRONMENT VARIABLES
-
-The following environment variables affect the operation of this module:
-
-=over
-
-=item C<PERL5_YACSMOKE_BASE>
-
-Loaded into L<CPANPLUS> by L<CPANPLUS::Config::YACSmoke>, sets the basedir where L<CPANPLUS> and
-CPANPLUS::YACSmoke related modules find the C<.cpanplus> directory for their settings
-
-  export PERL5_YACSMOKE_BASE=/home/moo/perls/conf/perl-5.8.9/
-
-Would set the base dir to C</home/moo/perls/conf/perl-5.8.9/.cpanplus/>
-
-=back
-
-Several environment variables get set by the module:
-
-=over
-
-=item C<AUTOMATED_TESTING>
-
-Set to 1 to indicate that we are currently running in an automated testing environment
-
-=item C<PERL_MM_USE_DEFAULT>
-
-Set to 1 MakeMaker and Module::Build's prompt functions will always return the default 
-without waiting for user input.
-
-=item C<MAILDOMAIN>
-
-L<Test::Reporter> uses this. YACSmoke will set this if it isn't already set. It will try to determine
-the domain from the C<email> setting in L<CPANPLUS>. If this is C<cpan.org> it will default to 
-C<cpantesters.org> ( the perl.org MX doesn't like people trying to impersonate it, for obvious reasons ).
-
-=back
-
 =head1 AUTHOR
 
 Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
@@ -583,7 +524,7 @@ Contributions and patience from Jos Boumans the L<CPANPLUS> guy!
 
 =head1 LICENSE
 
-Copyright E<copy> Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
+Copyright C<(c)> Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
 
 This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
 
@@ -593,10 +534,6 @@ L<CPANPLUS>
 
 L<CPANPLUS::Dist::YACSmoke>
 
-L<CPANPLUS::Config::YACSmoke>
-
 L<CPAN::YACSmoke>
 
-L<Test::Reporter>
-
 =cut
